@@ -191,11 +191,9 @@ int main(int argc, char *argv[])
 	printf("Waiting for votequorum events, press ^C to finish\n");
 	printf("-------------------\n");
 
-	while (1) {
-		if (votequorum_dispatch(g_handle, CS_DISPATCH_ALL) != CS_OK) {
-			fprintf(stderr, "votequorum_dispatch error\n");
-			return -1;
-		}
+	if (votequorum_dispatch(g_handle, CS_DISPATCH_BLOCKING) != CS_OK) {
+		fprintf(stderr, "votequorum_dispatch error\n");
+		return -1;
 	}
 
 	return 0;
